CSNameVec

Struct CSNameVec 

pub struct CSNameVec<C: Character, A: Clone>(/* private fields */);
A CSNameMap that uses a Vec to store the values for InternedCSName. Since the InternedCSNames are consecutive, we can use a Vec instead of a HMap.