ResolvedCSName

Trait ResolvedCSName 

pub trait ResolvedCSName<'a, C: Character>: Display {
    type Iter: Iterator<Item = C>;

    // Required methods
    fn iter(&self) -> Self::Iter;
    fn len(&self) -> usize;

    // Provided method
    fn is_empty(&self) -> bool { ... }
}
A control sequence name that has been interned needs to be resolved again to get the actual name / display it etc.

Required Associated Types

type Iter: Iterator<Item = C>

The type of the iterator over the characters of the control sequence name.

Required Methods

fn iter(&self) -> Self::Iter

Returns an iterator over the characters of the control sequence name.

fn len(&self) -> usize

Returns the length of the control sequence name in terms of the underlying Character type.

Provided Methods

fn is_empty(&self) -> bool

Implementations on Foreign Types

Source

impl<'a, C: Character> ResolvedCSName<'a, C> for &'a str

Source

type Iter = <C as Character>::Iter<'a>

Source

fn iter(&self) -> Self::Iter

Source

fn len(&self) -> usize

Implementors

Source

impl<'a, C: Character> ResolvedCSName<'a, C> for DisplayCSName<'a, C>

Source

type Iter = Copied<Iter<'a, C>>