pub struct CSNameVec<C: Character, A: Clone>(/* private fields */);Expand description
A CSNameMap that uses a Vec to store the values for InternedCSName.
Since the InternedCSNames are consecutive, we can use a Vec instead of a HMap.