pub trait ResolvedCSName<'a, C: Character>: Display {
type Iter: Iterator<Item = C>;
// Required methods
fn iter(&self) -> Self::Iter;
fn len(&self) -> usize;
// Provided method
fn is_empty(&self) -> bool { ... }
}Expand description
A control sequence name that has been interned needs to be resolved again to get the actual name / display it etc.